@@ -58,21 +58,6 @@ public:
      */
     Vector(const std::initializer_list<double> &list);
 
-    /** Default copy constructor */
-    Vector(const Vector &other) = default;
-
-    /** Default move constructor */
-    Vector(Vector &&other) = default;
-
-    /** Default destructor */
-    ~Vector() = default;
-
-    /** Default copy assignment operator */
-    Vector &operator=(const Vector &other) = default;
-
-    /** Default move assignment operator */
-    Vector &operator=(Vector &&other) = default;
-
     /**
      * @return dimension of vector
      */
@@ -307,7 +292,7 @@ Matrix Vector::outerProduct(const Vector &v1, const Vector &v2) {
     for (index i = 0; i < v1.getDimension(); ++i) {
         for (index j = 0; j < v2.getDimension(); ++j) {
             double result = v1[i] * v2[j];
-            if (fabs(result) >= FLOAT_EPSILON) {
+            if (std::fabs(result) >= FLOAT_EPSILON) {
                 triplets.push_back({i, j, result});
             }
         }
