@@ -1,5 +1,5 @@
 /*
- * AlgebraicSpanningEdgeCentrality.h
+ * AlgebraicSpanningEdgeCentrality.hpp
  *
  *  Created on: Jul 12, 2016
  *      Author: Michael Wegner (michael.wegner@student.kit.edu)
@@ -8,8 +8,8 @@
 #ifndef NETWORKIT_ALGEBRAIC_ALGORITHMS_ALGEBRAIC_SPANNING_EDGE_CENTRALITY_HPP_
 #define NETWORKIT_ALGEBRAIC_ALGORITHMS_ALGEBRAIC_SPANNING_EDGE_CENTRALITY_HPP_
 
-#include <cmath>
 #include <atomic>
+#include <cmath>
 
 #include <networkit/centrality/Centrality.hpp>
 #include <networkit/numerics/LAMG/Lamg.hpp>
@@ -20,18 +20,18 @@ namespace NetworKit {
  * @ingroup algebraic
  * Implementation of Spanning edge centrality with algebraic notation.
  */
-template<class Matrix>
+template <class Matrix>
 class AlgebraicSpanningEdgeCentrality : public Centrality {
 public:
     /**
-     * Constructs an instance of the AlgebraicSpanningEdgeCentrality algorithm for the given Graph @a graph.
-     * The tolerance @a tol is used to control the approximation error when approximating the spanning edge
-     * centrality for @a graph.
+     * Constructs an instance of the AlgebraicSpanningEdgeCentrality algorithm for the given Graph
+     * @a graph. The tolerance @a tol is used to control the approximation error when approximating
+     * the spanning edge centrality for @a graph.
      * @param graph
      * @param tol
      */
-    AlgebraicSpanningEdgeCentrality(const Graph& graph, double tol = 0.1) : Centrality(graph), tol(tol) {}
-
+    AlgebraicSpanningEdgeCentrality(const Graph &graph, double tol = 0.1)
+        : Centrality(graph), tol(tol) {}
 
     /**
      * Compute spanning edge centrality exactly.
@@ -47,14 +47,13 @@ private:
     double tol;
 };
 
-template<class Matrix>
+template <class Matrix>
 void AlgebraicSpanningEdgeCentrality<Matrix>::run() {
     const count n = G.numberOfNodes();
     const count m = G.numberOfEdges();
     scoreData.clear();
     scoreData.resize(m, 0.0);
 
-
     std::vector<Vector> rhs(m, Vector(n));
     this->G.parallelForEdges([&](node u, node v, edgeid e) {
         rhs[e][u] = +1;
@@ -69,23 +68,23 @@ void AlgebraicSpanningEdgeCentrality<Matrix>::run() {
 
     this->G.parallelForEdges([&](node u, node v, edgeid e) {
         double diff = solutions[e][u] - solutions[e][v];
-        scoreData[e] = fabs(diff);
+        scoreData[e] = std::fabs(diff);
     });
 
     hasRun = true;
 }
 
-template<class Matrix>
+template <class Matrix>
 void AlgebraicSpanningEdgeCentrality<Matrix>::runApproximation() {
     const count n = G.numberOfNodes();
     const count m = G.numberOfEdges();
     scoreData.clear();
     scoreData.resize(m, 0.0);
     double epsilon2 = tol * tol;
-    const count k = ceil(log2(n)) / epsilon2;
-    double randTab[2] = {1.0/sqrt(k), -1.0/sqrt(k)};
+    const count k = std::ceil(std::log2(n)) / epsilon2;
+    double randTab[2] = {1.0 / std::sqrt(k), -1.0 / std::sqrt(k)};
 
-    const auto rhsLoader = [&](count, Vector& yRow) -> Vector& {
+    const auto rhsLoader = [&](count, Vector &yRow) -> Vector & {
         yRow.fill(0);
         G.forEdges([&](node u, node v, edgeweight w, index) {
             double rand = randTab[Aux::Random::integer(1)];
@@ -96,12 +95,13 @@ void AlgebraicSpanningEdgeCentrality<Matrix>::runApproximation() {
     };
 
     std::vector<std::atomic<double>> scoreDataAtom(m);
-    const auto resultProcessor = [&](count, const Vector& zRow) {
+    const auto resultProcessor = [&](count, const Vector &zRow) {
         G.forEdges([&](node u, node v, edgeid e) {
             double diff = (zRow[u] - zRow[v]);
             diff *= diff;
-            for (double old = scoreDataAtom[e].load();
-                 !scoreDataAtom[e].compare_exchange_strong(old, old + diff, std::memory_order_relaxed););
+            for (double old = scoreDataAtom[e].load(); !scoreDataAtom[e].compare_exchange_strong(
+                     old, old + diff, std::memory_order_relaxed);)
+                ;
         });
     };
 
@@ -117,9 +117,6 @@ void AlgebraicSpanningEdgeCentrality<Matrix>::runApproximation() {
     hasRun = true;
 }
 
-
 } /* namespace NetworKit */
 
-
-
 #endif // NETWORKIT_ALGEBRAIC_ALGORITHMS_ALGEBRAIC_SPANNING_EDGE_CENTRALITY_HPP_
