@@ -1,5 +1,5 @@
 /*
- * SetIntersector.h
+ * SetIntersector.hpp
  *
  *  Created on: 14.05.2014
  *      Author: Henning
@@ -9,8 +9,8 @@
 #define NETWORKIT_AUXILIARY_SET_INTERSECTOR_HPP_
 
 #include <cstdint>
-#include <vector>
 #include <set>
+#include <vector>
 
 namespace Aux {
 
@@ -20,7 +20,7 @@ namespace Aux {
  * Query time: O(|A|+|B|) for two sets A and B.
  * Space complexity: upperBound + 64 bits.
  */
-template<class T>
+template <class T>
 class SetIntersector {
 public:
     /**
@@ -31,7 +31,7 @@ public:
     /**
      * @return Intersection of sets provided in @a A and @a B.
      */
-    std::set<T> intersect(const std::vector<T>& A, const std::vector<T>& B);
+    std::set<T> intersect(const std::vector<T> &A, const std::vector<T> &B);
 
 private:
     std::vector<bool> bv;
@@ -40,32 +40,29 @@ private:
 
 } // namespace Aux
 
-
-template<class T>
-inline Aux::SetIntersector<T>::SetIntersector(T upperBound): n(upperBound) {
+template <class T>
+inline Aux::SetIntersector<T>::SetIntersector(T upperBound) : n(upperBound) {
     bv.resize(n, false);
-
 }
 
-template<class T>
-inline std::set<T> Aux::SetIntersector<T>::intersect(const std::vector<T>& A,
-        const std::vector<T>& B)
-{
-    const std::vector<T>& smaller = (A.size() <= B.size()) ? A : B;
-    const std::vector<T>& larger = (A.size() <= B.size()) ? B : A;
+template <class T>
+inline std::set<T> Aux::SetIntersector<T>::intersect(const std::vector<T> &A,
+                                                     const std::vector<T> &B) {
+    const std::vector<T> &smaller = (A.size() <= B.size()) ? A : B;
+    const std::vector<T> &larger = (A.size() <= B.size()) ? B : A;
 
-    for (auto entry: smaller) {
+    for (auto entry : smaller) {
         bv[entry] = true;
     }
 
     std::set<T> result;
-    for (auto entry: larger) {
+    for (auto entry : larger) {
         if (bv[entry]) {
             result.insert(entry);
         }
     }
 
-    for (auto entry: smaller) {
+    for (auto entry : smaller) {
         bv[entry] = false;
     }
 
