@@ -1,8 +1,8 @@
 #ifndef NETWORKIT_BASE_DYN_ALGORITHM_HPP_
 #define NETWORKIT_BASE_DYN_ALGORITHM_HPP_
 
-#include <string>
 #include <stdexcept>
+#include <string>
 #include <networkit/dynamics/GraphEvent.hpp>
 
 namespace NetworKit {
@@ -23,10 +23,9 @@ public:
     /**
      * The generic update method for updating data structure after a batch of updates.
      */
-    virtual void updateBatch(const std::vector<GraphEvent>& batch) = 0;
-
+    virtual void updateBatch(const std::vector<GraphEvent> &batch) = 0;
 };
 
-} /* NetworKit */
+} // namespace NetworKit
 
 #endif // NETWORKIT_BASE_DYN_ALGORITHM_HPP_
