@@ -1,6 +1,5 @@
-// no-networkit-format
 /*
- * DynBetweenness.h
+ * DynBetweenness.hpp
  *
  *  Created on: 12.08.2015
  *      Author: Arie Slobbe, Elisabetta Bergamini
@@ -12,27 +11,25 @@
 #include <memory>
 #include <queue>
 
-#include <networkit/dynamics/GraphEvent.hpp>
-#include <networkit/base/DynAlgorithm.hpp>
 #include <networkit/auxiliary/PrioQueue.hpp>
+#include <networkit/base/DynAlgorithm.hpp>
 #include <networkit/centrality/Centrality.hpp>
+#include <networkit/dynamics/GraphEvent.hpp>
 
 namespace NetworKit {
 
-class CompareDist
-{
+class CompareDist {
 public:
-    bool operator()(std::pair<double,node> n1,std::pair<double,node> n2) {
+    bool operator()(std::pair<double, node> n1, std::pair<double, node> n2) {
         return n1.first > n2.first;
     }
 };
 
-
 /**
  * @ingroup centrality
  * Dynamic APSP.
  */
-class DynBetweenness: public Centrality, public DynAlgorithm {
+class DynBetweenness : public Centrality, public DynAlgorithm {
 
 public:
     /**
@@ -42,27 +39,26 @@ public:
      */
     DynBetweenness(const Graph &G);
 
-  /**
-   * Runs static betweenness centrality algorithm on the initial graph.
-   */
-  void run() override;
+    /**
+     * Runs static betweenness centrality algorithm on the initial graph.
+     */
+    void run() override;
 
-  /**
-  * Updates the betweenness centralities after an edge insertions on the graph.
-  * Notice: it works only with edge insertions.
-  *
-  * @param e The edge insertions.
-  */
-  void update(GraphEvent e) override;
-
-  /**
-  * Updates the betweenness centralities after a batch of edge insertions on the graph.
-  * Notice: it works only with edge insertions.
-  *
-  * @param batch The batch of edge insertions.
-  */
-  void updateBatch(const std::vector<GraphEvent>& batch) override;
+    /**
+     * Updates the betweenness centralities after an edge insertions on the graph.
+     * Notice: it works only with edge insertions.
+     *
+     * @param e The edge insertions.
+     */
+    void update(GraphEvent e) override;
 
+    /**
+     * Updates the betweenness centralities after a batch of edge insertions on the graph.
+     * Notice: it works only with edge insertions.
+     *
+     * @param batch The batch of edge insertions.
+     */
+    void updateBatch(const std::vector<GraphEvent> &batch) override;
 
     /** Returns number of visited pairs */
     count visPairs();
@@ -74,12 +70,15 @@ public:
 
     count numAffectedDep();
 
-  double getTimeDep();
-
+    double getTimeDep();
 
 private:
-    void increaseScore(std::vector<bool> & affected, node y, std::priority_queue<std::pair<double, node>, std::vector<std::pair<double,node>>, CompareDist> & Q);
-    void decreaseScore(std::vector<bool> & affected, node y, std::priority_queue<std::pair<double, node>, std::vector<std::pair<double,node>>, CompareDist> & Q);
+    void increaseScore(std::vector<bool> &affected, node y,
+                       std::priority_queue<std::pair<double, node>,
+                                           std::vector<std::pair<double, node>>, CompareDist> &Q);
+    void decreaseScore(std::vector<bool> &affected, node y,
+                       std::priority_queue<std::pair<double, node>,
+                                           std::vector<std::pair<double, node>>, CompareDist> &Q);
     node u;
     node v;
     edgeweight diameter = 0.0;
@@ -93,7 +92,7 @@ private:
 
     count affectedAPSP = 0;
     count affectedDep = 0;
-  double timeDep = 0;
+    double timeDep = 0;
 };
 
 } /* namespace NetworKit */
