@@ -9,17 +9,15 @@ template <typename AttributeT>
 class PrefixJaccardScore final : public EdgeScore<double> {
 
 public:
-    PrefixJaccardScore(const Graph& G, const std::vector<AttributeT>& attribute);
+    PrefixJaccardScore(const Graph &G, const std::vector<AttributeT> &attribute);
     double score(edgeid eid) override;
     double score(node u, node v) override;
     void run() override;
 
-
 private:
-    const std::vector<AttributeT>* inAttribute;
-
+    const std::vector<AttributeT> *inAttribute;
 };
 
-}
+} // namespace NetworKit
 
 #endif // NETWORKIT_EDGESCORES_PREFIX_JACCARD_SCORE_HPP_
