@@ -4,7 +4,6 @@
  *  Created on: May 28, 2013
  *      Author: forigem
  */
-// networkit-format
 
 #ifndef NETWORKIT_GENERATORS_BARABASI_ALBERT_GENERATOR_HPP_
 #define NETWORKIT_GENERATORS_BARABASI_ALBERT_GENERATOR_HPP_
@@ -24,27 +23,19 @@ class BarabasiAlbertGenerator final : public StaticGraphGenerator {
     count n0{0};   //!< The number of initial connected nodes
     bool batagelj; //!< Specifies whether to use batagelj's method or the original one
 
-    /**
-     * Implementation of ALG 5 of Batagelj, Brandes: Efficient Generation of Large Random Networks
-     * https://kops.uni-konstanz.de/bitstream/handle/123456789/5799/random.pdf?sequence=1
-     * Running time is O(n+m)
-     * @return The generated graph
-     */
-    Graph generateBatagelj();
-
-    Graph generateOriginal();
-
 public:
     BarabasiAlbertGenerator() = default;
 
     /**
      * This generator implements the preferential attachment model as introduced by Barabasi and
      * Albert[1]. The original algorithm is very slow and thus, the much faster method from Batagelj
-     * and Brandes[2] is implemented and the current default. The original method can be chosen by
-     * setting \p batagelj to false. [1] Barabasi, Albert: Emergence of Scaling in Random Networks
+     * and Brandes[2] is implemented and the current default. The original method is no longer
+     * supported and the \p batagelj parameter will be removed in future releases.
+     * [1] Barabasi, Albert: Emergence of Scaling in Random Networks
      *   http://arxiv.org/pdf/cond-mat/9910332.pdf
      * [2] ALG 5 of Batagelj, Brandes: Efficient Generation of Large Random Networks
      *   https://kops.uni-konstanz.de/bitstream/handle/123456789/5799/random.pdf?sequence=1
+     * Running time is O(n+m)
      *
      * The generator will emit a simple graph (given that the seed graph is simple), where all
      * new nodes are initially connected to k random neighbors.
