@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * HyperbolicSpace.hpp
  *
@@ -17,8 +16,8 @@
 #include <networkit/geometric/Point2DWithIndex.hpp>
 #include <networkit/viz/Point.hpp>
 
-using std::vector;
 using std::abs;
+using std::vector;
 
 namespace NetworKit {
 
@@ -44,7 +43,8 @@ public:
      *
      * Fill preallocated vectors with randomly sampled points in native coordinates
      */
-    static void fillPoints(vector<double> &angles, vector<double> &radii, double minPhi, double maxPhi, double minR, double maxR, double alpha);
+    static void fillPoints(vector<double> &angles, vector<double> &radii, double minPhi,
+                           double maxPhi, double minR, double maxR, double alpha);
 
     /**
      * @param firstangle angular coordinate of the first point
@@ -54,7 +54,8 @@ public:
      *
      * @return distance between two points in the poincare metric
      */
-    static double poincareMetric(double firstangle, double firstR, double secondangle, double secondR);
+    static double poincareMetric(double firstangle, double firstR, double secondangle,
+                                 double secondR);
 
     /**
      * @param firstangle angular coordinate of the first point
@@ -64,7 +65,8 @@ public:
      *
      * @return distance between two points in native hyperbolic representation
      */
-    static double nativeDistance(double firstangle, double firstR, double secondangle, double secondR);
+    static double nativeDistance(double firstangle, double firstR, double secondangle,
+                                 double secondR);
 
     /**
      * @param a first point in cartesian coordinates
@@ -74,8 +76,6 @@ public:
      */
     static double poincareMetric(Point2DWithIndex<double> a, Point2DWithIndex<double> b);
 
-
-
     /**
      * @param phi angular coordinate of point
      * @param r radial coordinate of point
@@ -87,7 +87,8 @@ public:
     /**
      * Convenience function for visualizations which expect coordinates as map<index,Point<float> >
      */
-    static std::map<index, Point<float> > polarToCartesian(const vector<double> &angles, const vector<double> &radii);
+    static std::map<index, Point<float>> polarToCartesian(const vector<double> &angles,
+                                                          const vector<double> &radii);
 
     /**
      * @param a cartesian coordinates
@@ -99,13 +100,19 @@ public:
     /**
      * Converts a hyperbolic circle to a Euclidean circle
      *
-     * @param hyperbolicCenter center of the hyperbolic circle, given in cartesian coordinates within the poincare disk
+     * @param hyperbolicCenter center of the hyperbolic circle, given in cartesian coordinates
+     * within the poincare disk
      * @param hyperbolicRadius radius of the hyperbolic circle
-     * @param euclideanCenter point to receive the center of the Euclidean circle, given in cartesian coordinates
+     * @param euclideanCenter point to receive the center of the Euclidean circle, given in
+     * cartesian coordinates
      * @param euclidenRadius double to receive the radius of the Euclidean circle
      */
-    static void getEuclideanCircle(Point2DWithIndex<double> hyperbolicCenter, double hyperbolicRadius, Point2DWithIndex<double> &euclideanCenter, double &euclideanRadius);
-    static void getEuclideanCircle(double r_h, double hyperbolicRadius, double &radialCoordOfEuclideanCenter, double &euclideanRadius);
+    static void getEuclideanCircle(Point2DWithIndex<double> hyperbolicCenter,
+                                   double hyperbolicRadius,
+                                   Point2DWithIndex<double> &euclideanCenter,
+                                   double &euclideanRadius);
+    static void getEuclideanCircle(double r_h, double hyperbolicRadius,
+                                   double &radialCoordOfEuclideanCenter, double &euclideanRadius);
 
     /**
      * Project radial coordinates of the hyperbolic plane into the Poincare disk model
@@ -128,70 +135,78 @@ public:
      * @param return Radius of a hyperbolic circle with the given area
      */
     static inline double hyperbolicAreaToRadius(double area) {
-        return acosh(area/(2*PI)+1);
+        return std::acosh(area / (2 * PI) + 1);
     }
 
     static inline double radiusToHyperbolicArea(double radius) {
-            return  2*PI*(cosh(radius)-1);
+        return 2 * PI * (std::cosh(radius) - 1);
     }
 
     static double getExpectedDegree(double n, double alpha, double R) {
-        double gamma = 2*alpha+1;
-        double xi = (gamma-1)/(gamma-2);
-        double firstSumTerm = exp(-R/2);
-        double secondSumTerm = exp(-alpha*R)*(alpha*(R/2)*((PI/4)*pow((1/alpha),2)-(PI-1)*(1/alpha)+(PI-2))-1);
-        double expectedDegree = (2/PI)*xi*xi*n*(firstSumTerm + secondSumTerm);
+        double gamma = 2 * alpha + 1;
+        double xi = (gamma - 1) / (gamma - 2);
+        double firstSumTerm = std::exp(-R / 2);
+        double secondSumTerm =
+            std::exp(-alpha * R)
+            * (alpha * (R / 2)
+                   * ((PI / 4) * std::pow((1 / alpha), 2) - (PI - 1) * (1 / alpha) + (PI - 2))
+               - 1);
+        double expectedDegree = (2 / PI) * xi * xi * n * (firstSumTerm + secondSumTerm);
         return expectedDegree;
     }
 
-    static double searchTargetRadiusForColdGraphs(double n, double k, double alpha, double epsilon) {
-        double gamma = 2*alpha+1;
-        double xiInv = ((gamma-2)/(gamma-1));
-        double v = k * (PI/2)*xiInv*xiInv;
-        double currentR = 2*log(n / v);
-        double lowerBound = currentR/2;
-        double upperBound = currentR*2;
+    static double searchTargetRadiusForColdGraphs(double n, double k, double alpha,
+                                                  double epsilon) {
+        double gamma = 2 * alpha + 1;
+        double xiInv = ((gamma - 2) / (gamma - 1));
+        double v = k * (PI / 2) * xiInv * xiInv;
+        double currentR = 2 * std::log(n / v);
+        double lowerBound = currentR / 2;
+        double upperBound = currentR * 2;
         assert(getExpectedDegree(n, alpha, lowerBound) > k);
         assert(getExpectedDegree(n, alpha, upperBound) < k);
         do {
-            currentR = (lowerBound + upperBound)/2;
+            currentR = (lowerBound + upperBound) / 2;
             double currentK = getExpectedDegree(n, alpha, currentR);
             if (currentK < k) {
                 upperBound = currentR;
             } else {
                 lowerBound = currentR;
             }
-        } while (abs(getExpectedDegree(n, alpha, currentR) - k) > epsilon );
+        } while (abs(getExpectedDegree(n, alpha, currentR) - k) > epsilon);
         return currentR;
     }
 
-    static double getTargetRadius(double n, double m, double alpha=1, double T=0, double epsilon = 0.01) {
+    static double getTargetRadius(double n, double m, double alpha = 1, double T = 0,
+                                  double epsilon = 0.01) {
         double result;
-        double plexp = 2*alpha+1;
-        double targetAvgDegree = (m/n)*2;
-        double xiInv = ((plexp-2)/(plexp-1));
+        double plexp = 2 * alpha + 1;
+        double targetAvgDegree = (m / n) * 2;
+        double xiInv = ((plexp - 2) / (plexp - 1));
         if (T == 0) {
             result = searchTargetRadiusForColdGraphs(n, targetAvgDegree, alpha, epsilon);
         } else {
-            double beta = 1/T;
-            if (T < 1){//cold regime
-                double Iinv = ((beta/PI)*sin(PI/beta));
-                double v = (targetAvgDegree*Iinv)*(PI/2)*xiInv*xiInv;
-                result = 2*log(n / v);
-            } else {//hot regime
-                double v = targetAvgDegree*(1-beta)*pow((PI/2), beta)*xiInv*xiInv;
-                result = 2*log(n/v)/beta;
+            double beta = 1 / T;
+            if (T < 1) { // cold regime
+                double Iinv = ((beta / PI) * std::sin(PI / beta));
+                double v = (targetAvgDegree * Iinv) * (PI / 2) * xiInv * xiInv;
+                result = 2 * std::log(n / v);
+            } else { // hot regime
+                double v = targetAvgDegree * (1 - beta) * std::pow((PI / 2), beta) * xiInv * xiInv;
+                result = 2 * std::log(n / v) / beta;
             }
         }
         return result;
     }
 
-    static inline double effectiveAreaInCell(double minPhi, double maxPhi, double minR, double maxR, double alpha) {
+    static inline double effectiveAreaInCell(double minPhi, double maxPhi, double minR, double maxR,
+                                             double alpha) {
         double deltaPhi = maxPhi - minPhi;
         assert(deltaPhi >= 0);
-        assert(deltaPhi <= 2*PI);
-        double ringArea = radiusToHyperbolicArea(alpha*EuclideanRadiusToHyperbolic(maxR)) - radiusToHyperbolicArea(alpha*EuclideanRadiusToHyperbolic(minR));
-        return ringArea*(deltaPhi/(2*PI));
+        assert(deltaPhi <= 2 * PI);
+        double ringArea = radiusToHyperbolicArea(alpha * EuclideanRadiusToHyperbolic(maxR))
+                          - radiusToHyperbolicArea(alpha * EuclideanRadiusToHyperbolic(minR));
+        return ringArea * (deltaPhi / (2 * PI));
     }
 
     /**
@@ -201,8 +216,9 @@ public:
      */
     static double hyperbolicSpaceInEuclideanCircle(double r_c, double d_c, double R);
 
-    static double maxRinSlice(double minPhi, double maxPhi, double phi_c, double r_c, double euRadius);
+    static double maxRinSlice(double minPhi, double maxPhi, double phi_c, double r_c,
+                              double euRadius);
 };
-}
+} // namespace NetworKit
 
 #endif // NETWORKIT_GEOMETRIC_HYPERBOLIC_SPACE_HPP_
