@@ -7,18 +7,22 @@
  *              Marvin Ritter <marvin.ritter@gmail.com>
  */
 
-// networkit-format
-
 #ifndef NETWORKIT_GRAPH_GRAPH_HPP_
 #define NETWORKIT_GRAPH_GRAPH_HPP_
 
 #include <algorithm>
+#include <fstream>
 #include <functional>
+#include <iostream>
+#include <memory>
 #include <numeric>
 #include <omp.h>
 #include <queue>
+#include <sstream>
 #include <stack>
 #include <stdexcept>
+#include <typeindex>
+#include <unordered_map>
 #include <unordered_set>
 #include <utility>
 #include <vector>
@@ -96,10 +100,6 @@ class CurveballMaterialization;
  */
 class Graph final {
 
-    friend class ParallelPartitionCoarsening;
-    friend class GraphBuilder;
-    friend class CurveballDetails::CurveballMaterialization;
-
     // graph attributes
     //!< current number of nodes
     count n;
@@ -145,6 +145,379 @@ class Graph final {
     //!< same schema (and same order!) as outEdges
     std::vector<std::vector<edgeid>> outEdgeIds;
 
+private:
+    // base class for all node attribute storages with attribute type info
+    // independent of the attribute type, holds bookkeeping info only:
+    // - attribute name
+    // - type info of derived (real storage holding) classes
+    // - which indices are valid
+    // - number of valid indices
+    // - the associated graph (who knows, which nodes exist)
+    // - the validity of the whole storage (initially true, false after detach)
+    class NodeAttributeStorageBase {
+    public:
+        NodeAttributeStorageBase(const Graph *graph, std::string name, std::type_index type)
+            : name{std::move(name)}, type{type}, theGraph{graph}, validStorage{true} {}
+
+        void invalidateStorage() { validStorage = false; }
+
+        const std::string &getName() const noexcept { return name; }
+
+        std::type_index getType() const noexcept { return type; }
+
+        bool isValid(node n) const noexcept { return n < valid.size() && valid[n]; }
+
+        // Called by Graph when node n is deleted.
+        void invalidate(node n) {
+            if (isValid(n)) {
+                valid[n] = false;
+                --validElements;
+            }
+        }
+
+    protected:
+        void markValid(node n) {
+            if (!theGraph->hasNode(n))
+                throw std::runtime_error("This node does not exist");
+
+            if (n >= valid.size())
+                valid.resize(n + 1);
+
+            if (!valid[n]) {
+                valid[n] = true;
+                ++validElements;
+            }
+        }
+
+        void checkIndex(node n) const {
+            if (!theGraph->hasNode(n)) {
+                throw std::runtime_error("This node does not exist");
+            }
+            if (!isValid(n)) {
+                throw std::runtime_error("Invalid attribute value");
+            }
+        }
+
+    private:
+        std::string name;
+        std::type_index type;
+        std::vector<bool> valid; // For each node: whether attribute is set or not.
+    protected:
+        index validElements = 0;
+        const Graph *theGraph;
+        bool validStorage; // Validity of the whole storage
+
+    }; // class NodeAttributeStorageBase
+
+    template <typename T>
+    class NodeAttribute;
+
+    template <typename T>
+    class NodeAttributeStorage : public NodeAttributeStorageBase {
+    public:
+        NodeAttributeStorage(const Graph *theGraph, std::string name)
+            : NodeAttributeStorageBase{theGraph, std::move(name), typeid(T)} {}
+
+        void resize(node i) {
+            if (i >= values.size())
+                values.resize(i + 1);
+        }
+
+        auto size() const noexcept { return validElements; }
+
+        void set(node i, T &&v) {
+            markValid(i);
+            resize(i);
+            values[i] = std::move(v);
+        }
+
+        // instead of returning an std::optional (C++17) we provide these
+        // C++14 options
+        // (1) throw an exception when invalid:
+        T get(node i) const { // may throw
+            checkIndex(i);
+            return values[i];
+        }
+
+        // (2) give default value when invalid:
+        T get(node i, T defaultT) const noexcept {
+            if (i >= values.size() || !isValid(i))
+                return defaultT;
+            return values[i];
+        }
+
+        friend NodeAttribute<T>;
+
+    private:
+        using NodeAttributeStorageBase::theGraph;
+        std::vector<T> values; // the real attribute storage
+    };                         // class NodeAttributeStorage<T>
+
+    template <typename T>
+    class NodeAttribute {
+    public:
+        class Iterator {
+        public:
+            // The value type of the nodes (i.e. nodes). Returned by
+            // operator*().
+            using value_type = T;
+
+            // Reference to the value_type, required by STL.
+            using reference = value_type &;
+
+            // Pointer to the value_type, required by STL.
+            using pointer = value_type *;
+
+            // STL iterator category.
+            using iterator_category = std::forward_iterator_tag;
+
+            // Signed integer type of the result of subtracting two pointers,
+            // required by STL.
+            using difference_type = ptrdiff_t;
+
+            Iterator() : storage{nullptr}, idx{0} {}
+            Iterator(NodeAttributeStorage<T> *storage) : storage{storage}, idx{0} {
+                if (storage) {
+                    nextValid();
+                }
+            }
+
+            Iterator &nextValid() {
+                while (storage && !storage->isValid(idx)) {
+                    if (idx >= storage->values.size()) {
+                        storage = nullptr;
+                        return *this;
+                    }
+                    ++idx;
+                }
+                return *this;
+            }
+
+            Iterator &operator++() {
+                if (!storage) {
+                    throw std::runtime_error("Invalid attribute iterator");
+                }
+                ++idx;
+                return nextValid();
+            }
+
+            auto operator*() const {
+                if (!storage) {
+                    throw std::runtime_error("Invalid attribute iterator");
+                }
+                return std::make_pair(idx, storage->values[idx]);
+            }
+
+            bool operator==(Iterator const &iter) const noexcept {
+                if (storage == nullptr && iter.storage == nullptr) {
+                    return true;
+                }
+                return storage == iter.storage && idx == iter.idx;
+            }
+
+            bool operator!=(Iterator const &iter) const noexcept { return !(*this == iter); }
+
+        private:
+            NodeAttributeStorage<T> *storage;
+            index idx;
+        }; // class Iterator
+
+    private:
+        class IndexProxy {
+            // a helper class for distinguished read and write on an indexed
+            // attribute
+            // operator[] on an attribute yields an IndexProxy holding
+            // location and index of access
+            //    - casting an IndexProxy to the attribute type reads the value
+            //    - assigning to it (operator=) writes the value
+        public:
+            IndexProxy(NodeAttributeStorage<T> *storage, index idx) : storage{storage}, idx{idx} {}
+
+            // reading at idx
+            operator T() const {
+                storage->checkIndex(idx);
+                return storage->values[idx];
+            }
+
+            // writing at idx
+            T &operator=(T &&other) {
+                storage->set(idx, std::move(other));
+                return storage->values[idx];
+            }
+
+        private:
+            NodeAttributeStorage<T> *storage;
+            index idx;
+        }; // class IndexProxy
+    public:
+        explicit NodeAttribute(std::shared_ptr<NodeAttributeStorage<T>> ownedStorage = nullptr)
+            : ownedStorage{ownedStorage}, valid{ownedStorage != nullptr} {}
+
+        NodeAttribute(NodeAttribute const &other)
+            : ownedStorage{other.ownedStorage}, valid{other.valid} {}
+
+        NodeAttribute &operator=(NodeAttribute other) {
+            this->swap(other);
+            return *this;
+        }
+
+        void swap(NodeAttribute &other) {
+            std::swap(ownedStorage, other.ownedStorage);
+            std::swap(valid, other.valid);
+        }
+
+        NodeAttribute(NodeAttribute &&other) noexcept
+            : ownedStorage{std::move(other.ownedStorage)}, valid{other.valid} {
+            other.valid = false;
+        }
+
+        auto begin() const {
+            checkAttribute();
+            return Iterator(ownedStorage.get()).nextValid();
+        }
+
+        auto end() const { return Iterator(nullptr); }
+
+        auto size() const noexcept { return ownedStorage->size(); }
+
+        void set(node i, T v) {
+            checkAttribute();
+            ownedStorage->set(i, std::move(v));
+        }
+
+        auto get(node i) const {
+            checkAttribute();
+            return ownedStorage->get(i);
+        }
+
+        auto get(node i, T defaultT) const {
+            checkAttribute();
+            return ownedStorage->get(i, defaultT);
+        }
+
+        IndexProxy operator[](node i) const {
+            checkAttribute();
+            return IndexProxy(ownedStorage.get(), i);
+        }
+
+        void checkAttribute() const {
+            if (!ownedStorage->validStorage)
+                throw std::runtime_error("Invalid attribute");
+        }
+
+        void write(std::string const &filename) const {
+            std::ofstream out(filename);
+            if (!out)
+                ERROR("cannot open ", filename, " for writing");
+
+            for (auto it = begin(); it != end(); ++it) {
+                auto pair = *it;
+                auto n = pair.first;  // node
+                auto v = pair.second; // value
+                out << n << "\t" << v << "\n";
+            }
+            out.close();
+        }
+
+        void read(const std::string &filename) {
+            std::ifstream in(filename);
+            if (!in) {
+                ERROR("cannot open ", filename, " for reading");
+            }
+            node n; // node
+            T v;    // value
+            std::string line;
+            while (std::getline(in, line)) {
+                std::istringstream istring(line);
+                istring >> n >> v;
+                set(n, v);
+            }
+        }
+
+    private:
+        std::shared_ptr<NodeAttributeStorage<T>> ownedStorage;
+        bool valid;
+    }; // class NodeAttribute
+
+    class NodeAttributeMap {
+        friend Graph;
+        const Graph *theGraph;
+
+    public:
+        std::unordered_map<std::string, std::shared_ptr<NodeAttributeStorageBase>> attrMap;
+
+        NodeAttributeMap(const Graph *g) : theGraph{g} {}
+
+        auto find(std::string const &name) {
+            auto it = attrMap.find(name);
+            if (it == attrMap.end()) {
+                throw std::runtime_error("No such attribute");
+            }
+            return it;
+        }
+
+        template <typename T>
+        auto attach(const std::string &name) {
+            auto ownedPtr = std::make_shared<NodeAttributeStorage<T>>(theGraph, std::string{name});
+            auto insertResult = attrMap.emplace(ownedPtr->getName(), ownedPtr);
+            auto success = insertResult.second;
+            if (!success) {
+                throw std::runtime_error("Attribute with same name already exists");
+            }
+            return NodeAttribute<T>{ownedPtr};
+        }
+
+        void detach(const std::string &name) {
+            auto it = find(name);
+            auto storage = it->second.get();
+            storage->invalidateStorage();
+            it->second.reset();
+            attrMap.erase(name);
+        }
+
+        template <typename T>
+        auto get(const std::string &name) {
+            auto it = find(name);
+            if (it->second.get()->getType() != typeid(T))
+                throw std::runtime_error("Type mismatch in nodeAttributes().get()");
+            return NodeAttribute<T>{std::static_pointer_cast<NodeAttributeStorage<T>>(it->second)};
+        }
+
+    }; // class NodeAttributeMap
+    NodeAttributeMap nodeAttributeMap;
+
+public:
+    auto &nodeAttributes() noexcept { return nodeAttributeMap; }
+
+    // wrap up some typed attributes for the cython interface:
+    //
+    auto attachNodeIntAttribute(const std::string &name) {
+        nodeAttributes().theGraph = this;
+        return nodeAttributes().attach<int>(name);
+    }
+
+    auto attachNodeDoubleAttribute(const std::string &name) {
+        nodeAttributes().theGraph = this;
+        return nodeAttributes().attach<double>(name);
+    }
+
+    auto attachNodeStringAttribute(const std::string &name) {
+        nodeAttributes().theGraph = this;
+        return nodeAttributes().attach<std::string>(name);
+    }
+
+    void detachNodeAttribute(std::string const &name) {
+        nodeAttributes().theGraph = this;
+        nodeAttributes().detach(name);
+    }
+
+    void detach(std::string const &name) { nodeAttributes().detach(name); }
+
+    using NodeIntAttribute = NodeAttribute<int>;
+    using NodeDoubleAttribute = NodeAttribute<double>;
+    using NodeStringAttribute = NodeAttribute<std::string>;
+
+private:
     /**
      * Returns the index of node u in the array of incoming edges of node v.
      * (for directed graphs inEdges is searched, while for indirected outEdges
@@ -988,9 +1361,9 @@ public:
      * @param weighted If set to <code>true</code>, the graph has edge weights.
      * @param directed If set to @c true, the graph will be directed.
      */
-    Graph(count n = 0, bool weighted = false, bool directed = false);
+    Graph(count n = 0, bool weighted = false, bool directed = false, bool edgesIndexed = false);
 
-    Graph(const Graph &G, bool weighted, bool directed);
+    Graph(const Graph &G, bool weighted, bool directed, bool edgesIndexed = false);
 
     /**
      * Generate a weighted graph from a list of edges. (Useful for small
@@ -1041,6 +1414,28 @@ public:
      */
     void preallocateDirected(node u, size_t outSize, size_t inSize);
 
+    /**
+     * Reserves memory in the node's edge containers for directed graphs.
+     *
+     * @param u the node memory should be reserved for
+     * @param outSize the amount of memory to reserve for out edges
+     *
+     * This function is thread-safe if called from different
+     * threads on different nodes.
+     */
+    void preallocateDirectedOutEdges(node u, size_t outSize);
+
+    /**
+     * Reserves memory in the node's edge containers for directed graphs.
+     *
+     * @param u the node memory should be reserved for
+     * @param inSize the amount of memory to reserve for in edges
+     *
+     * This function is thread-safe if called from different
+     * threads on different nodes.
+     */
+    void preallocateDirectedInEdges(node u, size_t inSize);
+
     /** EDGE IDS **/
 
     /**
@@ -1276,7 +1671,7 @@ public:
      * @param v Endpoint of edge.
      * @param weight Optional edge weight.
      * @param ew Optional edge weight.
-     * @param index Optional node index.
+     * @param index Optional edge index.
      */
     void addPartialEdge(Unsafe, node u, node v, edgeweight ew = defaultEdgeWeight,
                         uint64_t index = 0);
@@ -1289,7 +1684,7 @@ public:
      * @param u Endpoint of edge.
      * @param v Endpoint of edge.
      * @param ew Optional edge weight.
-     * @param index Optional node index.
+     * @param index Optional edge index.
      */
     void addPartialInEdge(Unsafe, node u, node v, edgeweight ew = defaultEdgeWeight,
                           uint64_t index = 0);
@@ -1302,7 +1697,7 @@ public:
      * @param u Endpoint of edge.
      * @param v Endpoint of edge.
      * @param ew Optional edge weight.
-     * @param index Optional node index.
+     * @param index Optional edge index.
      */
     void addPartialOutEdge(Unsafe, node u, node v, edgeweight ew = defaultEdgeWeight,
                            uint64_t index = 0);
@@ -1464,6 +1859,15 @@ public:
      */
     void setWeight(node u, node v, edgeweight ew);
 
+    /**
+     * Set the weight to the i-th neighbour of u.
+     *
+     * @param[in]	u	endpoint of edge
+     * @param[in]	i	index of the nexight
+     * @param[in]	weight	edge weight
+     */
+    void setWeightAtIthNeighbor(Unsafe, node u, index i, edgeweight ew);
+
     /**
      * Increase the weight of an edge. If the edge does not exist,
      * it will be inserted.
@@ -1554,6 +1958,15 @@ public:
         return NeighborWeightRange<true>(*this, u);
     }
 
+    /**
+     * Returns the index of node v in the array of outgoing edges of node u.
+     *
+     * @param u Node
+     * @param v Node
+     * @return index of node v in the array of outgoing edges of node u.
+     */
+    index indexOfNeighbor(node u, node v) const { return indexInOutEdgeArray(u, v); }
+
     /**
      * Return the i-th (outgoing) neighbor of @a u.
      *
@@ -1582,6 +1995,34 @@ public:
         return isWeighted() ? outEdgeWeights[u][i] : defaultEdgeWeight;
     }
 
+    /**
+     * Get i-th (outgoing) neighbor of @a u and the corresponding edge weight.
+     *
+     * @param u Node.
+     * @param i index; should be in [0, degreeOut(u))
+     * @return pair: i-th (outgoing) neighbor of @a u and the corresponding
+     * edge weight, or @c defaultEdgeWeight if unweighted.
+     */
+    std::pair<node, edgeweight> getIthNeighborWithWeight(node u, index i) const {
+        if (!hasNode(u) || i >= outEdges[u].size())
+            return {none, none};
+        return getIthNeighborWithWeight(unsafe, u, i);
+    }
+
+    /**
+     * Get i-th (outgoing) neighbor of @a u and the corresponding edge weight.
+     *
+     * @param u Node.
+     * @param i index; should be in [0, degreeOut(u))
+     * @return pair: i-th (outgoing) neighbor of @a u and the corresponding
+     * edge weight, or @c defaultEdgeWeight if unweighted.
+     */
+    std::pair<node, edgeweight> getIthNeighborWithWeight(Unsafe, node u, index i) const {
+        if (!isWeighted())
+            return {outEdges[u][i], defaultEdgeWeight};
+        return {outEdges[u][i], outEdgeWeights[u][i]};
+    }
+
     /**
      * Get i-th (outgoing) neighbor of @a u and the corresponding edge id.
      *
@@ -2221,7 +2662,11 @@ void Graph::sortEdges(Lambda lambda) {
         if (adjList.size() > indices.size())
             indices.resize(adjList.size());
 
-        const auto indicesEnd = indices.begin() + adjList.size();
+        const auto indicesEnd =
+            indices.begin()
+            + static_cast<
+                std::iterator_traits<std::vector<index>::const_iterator>::difference_type>(
+                adjList.size());
         std::iota(indices.begin(), indicesEnd, 0);
 
         if (isWeighted()) {
