@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * DotGraphWriter.hpp
  *
@@ -18,8 +17,10 @@ namespace NetworKit {
 
  * @ingroup io
  *
- * This class turns a graph into a very basic GraphViz file as documented in the official manual [1].
- * If a more thorough support is desired, please contact the developers: https://github.com/networkit/networkit
+ * This class turns a graph into a very basic GraphViz file as documented in the official manual
+ [1].
+ * If a more thorough support is desired, please contact the developers:
+ https://github.com/networkit/networkit
  *
  * [1] https://graphviz.gitlab.io/_pages/pdf/dotguide.pdf
  */
@@ -32,7 +33,6 @@ public:
      * @param[in]	path	The file path to be written to
      */
     void write(const Graph &G, const std::string &path) override;
-
 };
 
 } /* namespace NetworKit */
