@@ -1,5 +1,5 @@
 /*
- * MatrixMarketReader.h
+ * MatrixMarketReader.hpp
  *
  *  Created on: 25.07.2014
  *      Author: dhoske
@@ -19,16 +19,15 @@ namespace NetworKit {
  *
  * Only allows real, symmetric matrices.
  */
-class MatrixMarketReader: public MatrixReader {
+class MatrixMarketReader final : public MatrixReader {
 public:
+    MatrixMarketReader() = default;
 
-  MatrixMarketReader() = default;
+    CSRMatrix read(const std::string &path) override;
 
-  virtual CSRMatrix read(const std::string& path) override;
-
-  /** Reads the matrix in @a in. */
-  CSRMatrix read(std::istream& in);
+    /** Reads the matrix in @a in. */
+    CSRMatrix read(std::istream &in);
 };
 
-}
+} // namespace NetworKit
 #endif // NETWORKIT_IO_MATRIX_MARKET_READER_HPP_
