@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * DenseMatrix.cpp
  *
@@ -6,38 +5,43 @@
  *      Author: Michael Wegner (michael.wegner@student.kit.edu)
  */
 
-#include <networkit/algebraic/DenseMatrix.hpp>
 #include <algorithm>
+#include <networkit/algebraic/DenseMatrix.hpp>
 
 namespace NetworKit {
 
-DenseMatrix::DenseMatrix() : nRows(0), nCols(0), entries(std::vector<double>(0)), zero(0.0) {
-}
+DenseMatrix::DenseMatrix() : nRows(0), nCols(0), entries(std::vector<double>(0)), zero(0.0) {}
 
-DenseMatrix::DenseMatrix(const count dimension, const double zero) : nRows(dimension), nCols(dimension), entries(dimension*dimension, zero), zero(zero) {
-}
+DenseMatrix::DenseMatrix(const count dimension, const double zero)
+    : nRows(dimension), nCols(dimension), entries(dimension * dimension, zero), zero(zero) {}
 
-DenseMatrix::DenseMatrix(const count nRows, const count nCols, const double zero) : nRows(nRows), nCols(nCols), entries(nRows*nCols, zero), zero(zero) {
-}
+DenseMatrix::DenseMatrix(const count nRows, const count nCols, const double zero)
+    : nRows(nRows), nCols(nCols), entries(nRows * nCols, zero), zero(zero) {}
 
-DenseMatrix::DenseMatrix(const count dimension, const std::vector<Triplet>& triplets, const double zero) : DenseMatrix(dimension, dimension, triplets, zero) {
-}
+DenseMatrix::DenseMatrix(const count dimension, const std::vector<Triplet> &triplets,
+                         const double zero)
+    : DenseMatrix(dimension, dimension, triplets, zero) {}
 
-DenseMatrix::DenseMatrix(const count nRows, const count nCols, const std::vector<Triplet>& triplets, const double zero) : nRows(nRows), nCols(nCols), entries(nRows*nCols, zero), zero(zero) {
+DenseMatrix::DenseMatrix(const count nRows, const count nCols, const std::vector<Triplet> &triplets,
+                         const double zero)
+    : nRows(nRows), nCols(nCols), entries(nRows * nCols, zero), zero(zero) {
 #pragma omp parallel for
     for (omp_index k = 0; k < static_cast<omp_index>(triplets.size()); ++k) {
         entries[triplets[k].row * nCols + triplets[k].column] = triplets[k].value;
     }
 }
 
-DenseMatrix::DenseMatrix(const count nRows, const count nCols, const std::vector<double> &entries, const double zero) : nRows(nRows), nCols(nCols), entries(entries), zero(zero) {
+DenseMatrix::DenseMatrix(const count nRows, const count nCols, const std::vector<double> &entries,
+                         const double zero)
+    : nRows(nRows), nCols(nCols), entries(entries), zero(zero) {
     assert(entries.size() == nRows * nCols);
 }
 
 count DenseMatrix::nnzInRow(const index i) const {
     count nnz = 0;
-    for (index offset = i*numberOfColumns(); offset < (i+1)*numberOfColumns(); ++offset) {
-        if (fabs(entries[offset] - zero) > FLOAT_EPSILON) nnz++;
+    for (index offset = i * numberOfColumns(); offset < (i + 1) * numberOfColumns(); ++offset) {
+        if (std::fabs(entries[offset] - zero) > FLOAT_EPSILON)
+            nnz++;
     }
     return nnz;
 }
@@ -45,7 +49,8 @@ count DenseMatrix::nnzInRow(const index i) const {
 count DenseMatrix::nnz() const {
     count nnz = 0;
     for (index k = 0; k < entries.size(); ++k) {
-        if (fabs(entries[k] - zero) > FLOAT_EPSILON) nnz++;
+        if (std::fabs(entries[k] - zero) > FLOAT_EPSILON)
+            nnz++;
     }
     return nnz;
 }
@@ -83,7 +88,7 @@ Vector DenseMatrix::diagonal() const {
     Vector diagonal(std::min(numberOfRows(), numberOfColumns()), zero);
 #pragma omp parallel for
     for (omp_index i = 0; i < static_cast<omp_index>(diagonal.getDimension()); ++i) {
-        diagonal[i] = (*this)(i,i);
+        diagonal[i] = (*this)(i, i);
     }
 
     return diagonal;
@@ -91,23 +96,27 @@ Vector DenseMatrix::diagonal() const {
 
 DenseMatrix DenseMatrix::operator+(const DenseMatrix &other) const {
     assert(numberOfRows() == other.numberOfRows() && numberOfColumns() == other.numberOfColumns());
-    return DenseMatrix::binaryOperator(*this, other, [](double val1, double val2){return val1 + val2;});
+    return DenseMatrix::binaryOperator(*this, other,
+                                       [](double val1, double val2) { return val1 + val2; });
 }
 
-DenseMatrix& DenseMatrix::operator+=(const DenseMatrix &other) {
+DenseMatrix &DenseMatrix::operator+=(const DenseMatrix &other) {
     assert(numberOfRows() == other.numberOfRows() && numberOfColumns() == other.numberOfColumns());
-    *this = DenseMatrix::binaryOperator(*this, other, [](double val1, double val2){return val1 + val2;});
+    *this = DenseMatrix::binaryOperator(*this, other,
+                                        [](double val1, double val2) { return val1 + val2; });
     return *this;
 }
 
 DenseMatrix DenseMatrix::operator-(const DenseMatrix &other) const {
     assert(numberOfRows() == other.numberOfRows() && numberOfColumns() == other.numberOfColumns());
-    return DenseMatrix::binaryOperator(*this, other, [](double val1, double val2){return val1 - val2;});
+    return DenseMatrix::binaryOperator(*this, other,
+                                       [](double val1, double val2) { return val1 - val2; });
 }
 
-DenseMatrix& DenseMatrix::operator-=(const DenseMatrix &other) {
+DenseMatrix &DenseMatrix::operator-=(const DenseMatrix &other) {
     assert(numberOfRows() == other.numberOfRows() && numberOfColumns() == other.numberOfColumns());
-    *this = DenseMatrix::binaryOperator(*this, other, [](double val1, double val2){return val1 + val2;});
+    *this = DenseMatrix::binaryOperator(*this, other,
+                                        [](double val1, double val2) { return val1 + val2; });
     return *this;
 }
 
@@ -115,7 +124,7 @@ DenseMatrix DenseMatrix::operator*(double scalar) const {
     return DenseMatrix(*this) *= scalar;
 }
 
-DenseMatrix& DenseMatrix::operator*=(double scalar) {
+DenseMatrix &DenseMatrix::operator*=(double scalar) {
 #pragma omp parallel for
     for (omp_index k = 0; k < static_cast<omp_index>(entries.size()); ++k) {
         entries[k] *= scalar;
@@ -148,9 +157,9 @@ DenseMatrix DenseMatrix::operator*(const DenseMatrix &other) const {
     for (omp_index i = 0; i < static_cast<omp_index>(numberOfRows()); ++i) {
         index offset = i * other.numberOfColumns();
         for (index k = 0; k < numberOfColumns(); ++k) {
-            double val_i_k = (*this)(i,k);
+            double val_i_k = (*this)(i, k);
             for (index j = 0; j < other.numberOfColumns(); ++j) {
-                resultEntries[offset + j] += val_i_k * other(k,j);
+                resultEntries[offset + j] += val_i_k * other(k, j);
             }
         }
     }
@@ -162,26 +171,29 @@ DenseMatrix DenseMatrix::operator/(double divisor) const {
     return DenseMatrix(*this) /= divisor;
 }
 
-DenseMatrix& DenseMatrix::operator/=(double divisor) {
+DenseMatrix &DenseMatrix::operator/=(double divisor) {
     return *this *= 1.0 / divisor;
 }
 
 DenseMatrix DenseMatrix::transpose() const {
-    DenseMatrix transposedMatrix(numberOfColumns(), numberOfRows(), std::vector<double>(numberOfRows()*numberOfColumns(), getZero()));
-    forElementsInRowOrder([&](index i, index j, double value) {
-        transposedMatrix.setValue(j,i,value);
-    });
+    DenseMatrix transposedMatrix(
+        numberOfColumns(), numberOfRows(),
+        std::vector<double>(numberOfRows() * numberOfColumns(), getZero()));
+    forElementsInRowOrder(
+        [&](index i, index j, double value) { transposedMatrix.setValue(j, i, value); });
 
     return transposedMatrix;
 }
 
-DenseMatrix DenseMatrix::extract(const std::vector<index>& rowIndices, const std::vector<index>& columnIndices) const {
-    DenseMatrix result(rowIndices.size(), columnIndices.size(), std::vector<double>(rowIndices.size() * columnIndices.size(), getZero()));
+DenseMatrix DenseMatrix::extract(const std::vector<index> &rowIndices,
+                                 const std::vector<index> &columnIndices) const {
+    DenseMatrix result(rowIndices.size(), columnIndices.size(),
+                       std::vector<double>(rowIndices.size() * columnIndices.size(), getZero()));
     for (index i = 0; i < rowIndices.size(); ++i) {
         for (index j = 0; j < columnIndices.size(); ++j) {
             double value = (*this)(rowIndices[i], columnIndices[j]);
-            if (fabs(value - getZero()) > FLOAT_EPSILON) {
-                result.setValue(i,j,value);
+            if (std::fabs(value - getZero()) > FLOAT_EPSILON) {
+                result.setValue(i, j, value);
             }
         }
     }
@@ -189,24 +201,24 @@ DenseMatrix DenseMatrix::extract(const std::vector<index>& rowIndices, const std
     return result;
 }
 
-void DenseMatrix::assign(const std::vector<index>& rowIndices, const std::vector<index>& columnIndices, const DenseMatrix& source) {
+void DenseMatrix::assign(const std::vector<index> &rowIndices,
+                         const std::vector<index> &columnIndices, const DenseMatrix &source) {
     assert(rowIndices.size() == source.numberOfRows());
     assert(columnIndices.size() == source.numberOfColumns());
 
     for (index i = 0; i < rowIndices.size(); ++i) {
-        source.forElementsInRow(i, [&](index j, double value) {
-            setValue(rowIndices[i], columnIndices[j], value);
-        });
+        source.forElementsInRow(
+            i, [&](index j, double value) { setValue(rowIndices[i], columnIndices[j], value); });
     }
 }
 
 void DenseMatrix::LUDecomposition(DenseMatrix &matrix) {
     assert(matrix.numberOfRows() == matrix.numberOfColumns());
-    for (index k = 0; k < matrix.numberOfRows()-1; ++k) {
-        for (index i = k+1; i < matrix.numberOfRows(); ++i) {
-            matrix.setValue(i, k, matrix(i,k) / matrix(k,k));
-            for (index j = k+1; j < matrix.numberOfRows(); ++j) {
-                matrix.setValue(i, j, matrix(i,j) - (matrix(i,k) * matrix(k,j)));
+    for (index k = 0; k < matrix.numberOfRows() - 1; ++k) {
+        for (index i = k + 1; i < matrix.numberOfRows(); ++i) {
+            matrix.setValue(i, k, matrix(i, k) / matrix(k, k));
+            for (index j = k + 1; j < matrix.numberOfRows(); ++j) {
+                matrix.setValue(i, j, matrix(i, j) - (matrix(i, k) * matrix(k, j)));
             }
         }
     }
@@ -215,22 +227,20 @@ void DenseMatrix::LUDecomposition(DenseMatrix &matrix) {
 Vector DenseMatrix::LUSolve(const DenseMatrix &LU, const Vector &b) {
     Vector x = b;
 
-    for (index i = 0; i < LU.numberOfRows()-1; ++i) { // forward substitution
-        for (index j = i+1; j < LU.numberOfRows(); ++j) {
-            x[j] -= x[i] * LU(j,i);
+    for (index i = 0; i < LU.numberOfRows() - 1; ++i) { // forward substitution
+        for (index j = i + 1; j < LU.numberOfRows(); ++j) {
+            x[j] -= x[i] * LU(j, i);
         }
     }
 
     for (index i = LU.numberOfRows(); i-- > 0;) { // backward substitution
-        x[i] /= LU(i,i);
+        x[i] /= LU(i, i);
         for (index j = 0; j < i; ++j) {
-            x[j] -= x[i] * LU(j,i);
+            x[j] -= x[i] * LU(j, i);
         }
     }
 
     return x;
 }
 
-
-
 } /* namespace NetworKit */
