@@ -5,8 +5,6 @@
  *      Author: Eugenio Angriman <angrimae@hu-berlin.de>
  */
 
-// networkit-format
-
 #include <omp.h>
 #include <utility>
 
@@ -25,8 +23,7 @@ GroupClosenessGrowShrinkImpl<WeightType>::GroupClosenessGrowShrinkImpl(const Gra
                                                                        count maxIterations)
     : G(&G), group(std::move(initGroup)), extended(extended),
       insertions(insertions == 0 ? computeConsecutiveInsertions(G, group.size()) : insertions),
-      maxIterations(maxIterations), heap(CompareDistance(distance)),
-      heap_(CompareDistance(distance_)) {
+      maxIterations(maxIterations), heap(distance), heap_(distance_) {
 
     if (G.isDirected())
         std::runtime_error("Error, this algorithm does not support directed graphs.");
@@ -404,8 +401,11 @@ node GroupClosenessGrowShrinkImpl<WeightType>::estimateHighestDecrement() {
             }
         });
 
-        if (distance[x] && (G->isWeighted() || (!leaf || distance[x] == WeightType{1})))
-            stack[stackSize++] = x;
+        if (distance[x] == 0)
+            continue; // Ignore vertices in the group
+
+        if (G->isWeighted() || extended || (!leaf || distance[x] == WeightType{1}))
+            stack[stackSize++] = x; // Avoid to consider DAG leaves if running non-extended GS
 
     } while (!(G->isWeighted() ? heap.empty() : q.empty()));
 
