@@ -27,6 +27,7 @@
 #include <networkit/centrality/DynTopHarmonicCloseness.hpp>
 #include <networkit/centrality/EigenvectorCentrality.hpp>
 #include <networkit/centrality/EstimateBetweenness.hpp>
+#include <networkit/centrality/ForestCentrality.hpp>
 #include <networkit/centrality/GedWalk.hpp>
 #include <networkit/centrality/GroupCloseness.hpp>
 #include <networkit/centrality/GroupClosenessGrowShrink.hpp>
@@ -40,6 +41,7 @@
 #include <networkit/centrality/KatzCentrality.hpp>
 #include <networkit/centrality/LaplacianCentrality.hpp>
 #include <networkit/centrality/LocalClusteringCoefficient.hpp>
+#include <networkit/centrality/LocalSquareClusteringCoefficient.hpp>
 #include <networkit/centrality/PageRank.hpp>
 #include <networkit/centrality/PermanenceCentrality.hpp>
 #include <networkit/centrality/SpanningEdgeCentrality.hpp>
@@ -589,14 +591,14 @@ TEST_F(CentralityGTest, testEigenvectorCentrality) {
 
     // computed with Matlab
     const double tol = 1e-4;
-    EXPECT_NEAR(0.2254, fabs(cen[0]), tol);
-    EXPECT_NEAR(0.1503, fabs(cen[1]), tol);
-    EXPECT_NEAR(0.5290, fabs(cen[2]), tol);
-    EXPECT_NEAR(0.4508, fabs(cen[3]), tol);
-    EXPECT_NEAR(0.3006, fabs(cen[4]), tol);
-    EXPECT_NEAR(0.5290, fabs(cen[5]), tol);
-    EXPECT_NEAR(0.2254, fabs(cen[6]), tol);
-    EXPECT_NEAR(0.1503, fabs(cen[7]), tol);
+    EXPECT_NEAR(0.2254, std::fabs(cen[0]), tol);
+    EXPECT_NEAR(0.1503, std::fabs(cen[1]), tol);
+    EXPECT_NEAR(0.5290, std::fabs(cen[2]), tol);
+    EXPECT_NEAR(0.4508, std::fabs(cen[3]), tol);
+    EXPECT_NEAR(0.3006, std::fabs(cen[4]), tol);
+    EXPECT_NEAR(0.5290, std::fabs(cen[5]), tol);
+    EXPECT_NEAR(0.2254, std::fabs(cen[6]), tol);
+    EXPECT_NEAR(0.1503, std::fabs(cen[7]), tol);
 }
 
 TEST_F(CentralityGTest, testPageRankCentrality) {
@@ -631,14 +633,14 @@ TEST_F(CentralityGTest, testPageRankCentrality) {
 
     // compare to Matlab results
     const double tol = 1e-4;
-    EXPECT_NEAR(0.0753, fabs(cen[0]), tol);
-    EXPECT_NEAR(0.0565, fabs(cen[1]), tol);
-    EXPECT_NEAR(0.2552, fabs(cen[2]), tol);
-    EXPECT_NEAR(0.1319, fabs(cen[3]), tol);
-    EXPECT_NEAR(0.0942, fabs(cen[4]), tol);
-    EXPECT_NEAR(0.2552, fabs(cen[5]), tol);
-    EXPECT_NEAR(0.0753, fabs(cen[6]), tol);
-    EXPECT_NEAR(0.0565, fabs(cen[7]), tol);
+    EXPECT_NEAR(0.0753, std::fabs(cen[0]), tol);
+    EXPECT_NEAR(0.0565, std::fabs(cen[1]), tol);
+    EXPECT_NEAR(0.2552, std::fabs(cen[2]), tol);
+    EXPECT_NEAR(0.1319, std::fabs(cen[3]), tol);
+    EXPECT_NEAR(0.0942, std::fabs(cen[4]), tol);
+    EXPECT_NEAR(0.2552, std::fabs(cen[5]), tol);
+    EXPECT_NEAR(0.0753, std::fabs(cen[6]), tol);
+    EXPECT_NEAR(0.0565, std::fabs(cen[7]), tol);
 }
 
 TEST_F(CentralityGTest, benchSequentialBetweennessCentralityOnRealGraph) {
@@ -1189,6 +1191,27 @@ TEST_F(CentralityGTest, testLocalClusteringCoefficientUndirected2) {
     EXPECT_EQ(reference, lccScores);
 }
 
+TEST_F(CentralityGTest, testLocalSquareClusteringCoefficientUndirected) {
+    Graph G(7, false, false);
+    G.addEdge(0, 1);
+    G.addEdge(1, 2);
+    G.addEdge(2, 3);
+    G.addEdge(3, 0);
+    G.addEdge(3, 4);
+    G.addEdge(4, 5);
+    G.addEdge(5, 6);
+    G.addEdge(6, 3);
+    LocalSquareClusteringCoefficient lscc(G);
+    lscc.run();
+    std::vector<double> lccScores = lscc.scores();
+    std::vector<double> reference = {
+        0.3333333333333333, 1.0, 0.3333333333333333, 0.2,
+        0.3333333333333333, 1.0, 0.3333333333333333
+    };
+
+    EXPECT_EQ(reference, lccScores);
+}
+
 TEST_F(CentralityGTest, testSimplePermanence) {
     Graph G(15, false, false);
     G.addEdge(0, 1);
@@ -2197,4 +2220,40 @@ TEST_P(CentralityGTest, testGroupClosenessLocalSearch) {
     EXPECT_EQ(gcls2.numberOfIterations(), 0);
 }
 
+TEST_F(CentralityGTest, testForestCentrality) {
+    {
+        // Directed graphs are not supported
+        Graph G(10, true, true);
+        G.addEdge(0, 1);
+        EXPECT_THROW(ForestCentrality(G, 0), std::runtime_error);
+
+        // Non-augmented graph
+        G = GraphTools::toUndirected(G);
+        G = GraphTools::toUnweighted(G);
+        EXPECT_THROW(ForestCentrality(G, 0), std::runtime_error);
+
+        // Augmented but non-compact graph
+        node root = GraphTools::augmentGraph(G);
+        G.removeNode(5);
+        EXPECT_THROW(ForestCentrality(G, root), std::runtime_error);
+    }
+
+    Aux::Random::setSeed(42, true);
+    auto G = HyperbolicGenerator(200).generate();
+    const node root = GraphTools::augmentGraph(G);
+
+    const double eps = 0.05;
+
+    ForestCentrality fc(G, root, eps);
+    fc.run();
+    EXPECT_GT(fc.getNumberOfSamples(), 0);
+    const auto apxDiag = fc.getDiagonal();
+
+    ApproxElectricalCloseness ele(G);
+    const auto diag = ele.computeExactDiagonal();
+    G.forNodes([&](node u) { EXPECT_NEAR(apxDiag[u], diag[u], eps); });
+
+    EXPECT_EQ(fc.scores().size(), G.upperNodeIdBound());
+}
+
 } /* namespace NetworKit */
