@@ -20,15 +20,11 @@ CommunityDetectionAlgorithm::CommunityDetectionAlgorithm(const Graph& G) : Algor
 CommunityDetectionAlgorithm::CommunityDetectionAlgorithm(const Graph &G, Partition baseClustering)
     : Algorithm(), G(&G), result(std::move(baseClustering)) {}
 
-Partition CommunityDetectionAlgorithm::getPartition() {
+const Partition &CommunityDetectionAlgorithm::getPartition() const {
     if(!hasRun) {
         throw std::runtime_error("Call run()-function first.");
     }
     return result;
 }
 
-std::string CommunityDetectionAlgorithm::toString() const {
-    return "TODO: string representation of clusterer";
-}
-
 } /* namespace NetworKit */
