@@ -497,16 +497,12 @@ void LouvainMapEquation::calculateInitialClusterCutAndVolume() {
     }
 }
 
-std::string LouvainMapEquation::toString() const {
-    return "LouvainMapEquation";
-}
-
 #ifndef NDEBUG
 
 double LouvainMapEquation::plogpRel(double w) {
     if (w > 0) {
         double p = w / totalVolume;
-        return p * log(p);
+        return p * std::log(p);
     }
     return 0;
 }
