@@ -62,6 +62,10 @@ TEST_F(ConnectedComponentsGTest, testConnectedComponentsTiny) {
     EXPECT_TRUE(ccs.componentOfNode(3) == ccs.componentOfNode(7));
 }
 
+TEST_F(ConnectedComponentsGTest, testConnectedComponentsDirected) {
+    Graph G(5, false, true);
+    EXPECT_THROW(ConnectedComponents{G}, std::runtime_error);
+}
 
 TEST_F(ConnectedComponentsGTest, testConnectedComponents) {
     // construct graph
@@ -79,10 +83,11 @@ TEST_F(ConnectedComponentsGTest, testParallelConnectedComponents) {
 
     for (auto graphName: graphs) {
         Graph G = reader.read("input/" + graphName + ".graph");
-        ParallelConnectedComponents cc(G);
-        cc.runSequential();
-        count seqNum = cc.numberOfComponents();
+        ConnectedComponents cc(G);
         cc.run();
+        count seqNum = cc.numberOfComponents();
+        ParallelConnectedComponents ccPar(G);
+        ccPar.run();
         count parNum = cc.numberOfComponents();
         DEBUG("Number of components: ", seqNum);
         EXPECT_EQ(seqNum, parNum);
@@ -110,11 +115,11 @@ TEST_F(ConnectedComponentsGTest, testParallelConnectedComponentsWithDeletedNodes
     }
 
     {
-        ParallelConnectedComponents cc(G);
+        ParallelConnectedComponents ccPar(G);
+        ccPar.run();
+        ConnectedComponents cc(G);
         cc.run();
-        EXPECT_EQ(1, cc.numberOfComponents()) << "The complete graph with 10 nodes removed has still just one connected component (run())";
-        cc.runSequential();
-        EXPECT_EQ(1, cc.numberOfComponents()) << "The complete graph with 10 nodes removed has still just one connected component (runSequential())";
+        EXPECT_EQ(cc.numberOfComponents(), ccPar.numberOfComponents()) << "The complete graph with 10 nodes removed has still just one connected component (run())";
     }
 
 }
@@ -254,10 +259,7 @@ TEST_F(ConnectedComponentsGTest, testStronglyConnectedComponents) {
 
 TEST_F(ConnectedComponentsGTest, testDynConnectedComponentsTiny) {
     // construct graph
-    Graph g;
-    for (count i = 0; i < 20; i++) {
-        g.addNode();
-    }
+    Graph g(20);
     g.addEdge(0,1,0);
     g.addEdge(1,2,0);
     g.addEdge(2,4,0);
@@ -318,78 +320,54 @@ TEST_F(ConnectedComponentsGTest, testDynConnectedComponentsTiny) {
 
 
 TEST_F(ConnectedComponentsGTest, testDynConnectedComponents) {
-    // construct graph
-    METISGraphReader reader;
-    Graph G = reader.read("input/PGPgiantcompo.graph");
-    DynConnectedComponents dccs(G);
-    dccs.run();
-    ConnectedComponents cc(G);
-    cc.run();
-    DEBUG("Number of components: ", dccs.numberOfComponents());
-    // Testing static run.
-    EXPECT_EQ(cc.numberOfComponents(), dccs.numberOfComponents());
+    auto G = METISGraphReader{}.read("input/karate.graph");
+    DynConnectedComponents dw(G);
+    dw.run();
 
-    int numberOfTests = 500;
+    const std::unordered_set<Edge> edges{G.edgeRange().begin(), G.edgeRange().end()};
 
-    // Probability to perform an edge insertion or removal.
-    float p = 0.5;
-    srand (time(NULL));
-    for (int i = 0; i < numberOfTests; ++i) {
-        node u = 0;
-        node v = 1;
+    auto testComponents = [&]() {
+        ConnectedComponents wc(G);
+        wc.run();
 
-        // Perform edge insertion
-        if (((double) rand() / (RAND_MAX)) > p) {
-            while (G.hasEdge(u, v)) {
-                u = GraphTools::randomNode(G);
-                v = GraphTools::randomNode(G);
-            }
-            G.addEdge(u, v);
-            dccs.update(GraphEvent(GraphEvent::EDGE_ADDITION, u, v, 0));
-        }
-        else {
-            while (!G.hasEdge(u, v)) {
-                std::pair<node, node> edge = GraphTools::randomEdge(G);
-                u = edge.first;
-                v = edge.second;
-            }
-            G.removeEdge(u, v);
-            dccs.update(GraphEvent(GraphEvent::EDGE_REMOVAL, u, v, 0));
-        }
+        EXPECT_EQ(wc.numberOfComponents(), dw.numberOfComponents());
+
+        // Mapping from static algo components to dyn algo components
+        std::unordered_map<index, index> compMap;
+        // Components already seen in dynamic algo
+        std::unordered_set<index> seenInDyn;
+
+        G.forNodes([&](node u) {
+            const auto staticCmpU = wc.componentOfNode(u), dynCmpU = dw.componentOfNode(u);
+            const auto it = compMap.find(staticCmpU);
+            if (it == compMap.end()) {
+                EXPECT_EQ(seenInDyn.find(dynCmpU), seenInDyn.end());
+                compMap.emplace(staticCmpU, dynCmpU);
+                seenInDyn.insert(dynCmpU);
+            } else
+                EXPECT_EQ(it->second, dynCmpU);
+        });
+    };
+
+    // Remove all edges
+    for (const auto &edge : edges) {
+        G.removeEdge(edge.u, edge.v);
+        dw.update(GraphEvent(GraphEvent::EDGE_REMOVAL, edge.u, edge.v));
+        testComponents();
     }
 
-    cc.run();
-    EXPECT_EQ(cc.numberOfComponents(), dccs.numberOfComponents());
-
-    // Testing batch update.
-    std::vector<GraphEvent> batch(numberOfTests);
-    for (int i = 0; i < numberOfTests; ++i) {
-        node u = GraphTools::randomNode(G);
-        node v = GraphTools::randomNode(G);
-        if (((double) rand() / (RAND_MAX)) > -1) {
-            while (G.hasEdge(u, v)) {
-                u = GraphTools::randomNode(G);
-                v = GraphTools::randomNode(G);
-            }
-            batch[i] = GraphEvent(GraphEvent::EDGE_ADDITION, u, v, 0);
-            G.addEdge(u, v);
-        }
-        else {
-            while (!G.hasEdge(u, v)) {
-                std::pair<node, node> edge = GraphTools::randomEdge(G);
-                u = edge.first;
-                v = edge.second;
-            }
-            batch[i] = GraphEvent(GraphEvent::EDGE_REMOVAL, u, v, 0);
-            G.removeEdge(u, v);
-        }
+    // Add all edges
+    for (const auto &edge : edges) {
+        G.addEdge(edge.u, edge.v);
+        dw.update(GraphEvent(GraphEvent::EDGE_ADDITION, edge.u, edge.v));
+        testComponents();
     }
-
-    dccs.updateBatch(batch);
-    cc.run();
-    EXPECT_EQ(cc.numberOfComponents(), dccs.numberOfComponents());
 }
 
+TEST_F(ConnectedComponentsGTest, testDynConnectedComponentsDirected) {
+    Graph g(0, false, true);
+    EXPECT_THROW(DynConnectedComponents{g}, std::runtime_error);
+}
 
 TEST_F(ConnectedComponentsGTest, testWeaklyConnectedComponentsTiny) {
     // construct graph
@@ -427,6 +405,11 @@ TEST_F(ConnectedComponentsGTest, testWeaklyConnectedComponentsTiny) {
     EXPECT_TRUE(wcc.componentOfNode(3) == wcc.componentOfNode(7));
 }
 
+TEST_F(ConnectedComponentsGTest, testConnectedComponentsUndirected) {
+    Graph G(5); // Undirected
+    EXPECT_THROW(WeaklyConnectedComponents{G}, std::runtime_error);
+}
+
 TEST_F(ConnectedComponentsGTest, testWeaklyConnectedComponents) {
     // construct graph
     EdgeListReader directReader(' ', 0, "%", false, true);
@@ -495,86 +478,70 @@ TEST_F(ConnectedComponentsGTest, testDynWeaklyConnectedComponentsTiny) {
         if (e.type == GraphEvent::EDGE_REMOVAL) {
             g.removeEdge(e.u, e.v);
         }
+        dw.update(e);
     }
 
-    dw.updateBatch(batch);
     EXPECT_EQ(4, dw.numberOfComponents());
-    EXPECT_TRUE(dw.componentOfNode(0) != dw.componentOfNode(14));
-    EXPECT_TRUE(dw.componentOfNode(9) == dw.componentOfNode(11));
-    EXPECT_TRUE(dw.componentOfNode(3) != dw.componentOfNode(9));
+
+    EXPECT_EQ(dw.componentOfNode(0), dw.componentOfNode(2));
+    EXPECT_NE(dw.componentOfNode(0), dw.componentOfNode(14));
+    EXPECT_EQ(dw.componentOfNode(9), dw.componentOfNode(11));
+    EXPECT_NE(dw.componentOfNode(3), dw.componentOfNode(9));
+    EXPECT_NE(dw.componentOfNode(3), dw.componentOfNode(0));
 }
 
 
 TEST_F(ConnectedComponentsGTest, testDynWeaklyConnectedComponents) {
-    // Read graph
-    KONECTGraphReader reader;
-    Graph G = reader.read("input/foodweb-baydry.konect");
+    auto G = KONECTGraphReader{}.read("input/foodweb-baydry.konect");
     DynWeaklyConnectedComponents dw(G);
     dw.run();
-    WeaklyConnectedComponents wc(G);
-    wc.run();
 
-    DEBUG("Number of components: ", dw.numberOfComponents());
-    // Testing static run.
-    EXPECT_EQ(wc.numberOfComponents(), dw.numberOfComponents());
+    const std::unordered_set<Edge> edges{G.edgeRange().begin(), G.edgeRange().end()};
 
-    int numberOfTests = 1000;
-    // Probability to perform an edge insertion or removal.
-    float p = 0.5;
-    for (int i = 0; i < numberOfTests; ++i) {
-        node u = 0;
-        node v = 1;
-        // Perform edge insertion
-        if (((double) rand() / (RAND_MAX)) > p) {
-            while (G.hasEdge(u, v)) {
-                u = GraphTools::randomNode(G);
-                v = GraphTools::randomNode(G);
-            }
-            G.addEdge(u, v);
-            dw.update(GraphEvent(GraphEvent::EDGE_ADDITION, u, v, 0));
-        }
-        else {
-            while (!G.hasEdge(u, v) || u == v) {
-                std::pair<node, node> edge = GraphTools::randomEdge(G);
-                u = edge.first;
-                v = edge.second;
-            }
-            G.removeEdge(u, v);
-            dw.update(GraphEvent(GraphEvent::EDGE_REMOVAL, u, v, 0));
-        }
-    }
-    wc.run();
-    EXPECT_EQ(wc.numberOfComponents(), dw.numberOfComponents());
+    auto testComponents = [&]() {
+        WeaklyConnectedComponents wc(G);
+        wc.run();
 
-    // Testing batch update.
-    std::vector<GraphEvent> batch(numberOfTests);
-    for (int i = 0; i < numberOfTests; ++i) {
-        node u = GraphTools::randomNode(G);
-        node v = GraphTools::randomNode(G);
-        if (((double) rand() / (RAND_MAX)) > p) {
-            while (G.hasEdge(u, v) || u == v) {
-                u = GraphTools::randomNode(G);
-                v = GraphTools::randomNode(G);
-            }
-            batch[i] = GraphEvent(GraphEvent::EDGE_ADDITION, u, v, 0);
-            G.addEdge(u, v);
-        }
-        else {
-            while (!G.hasEdge(u, v) || u == v) {
-                std::pair<node, node> edge = GraphTools::randomEdge(G);
-                u = edge.first;
-                v = edge.second;
-            }
-            G.removeEdge(u, v);
-            batch[i] = GraphEvent(GraphEvent::EDGE_REMOVAL, u, v, 0);
-        }
+        EXPECT_EQ(wc.numberOfComponents(), dw.numberOfComponents());
+
+        // Mapping from static algo components to dyn algo components
+        std::unordered_map<index, index> compMap;
+        // Components already seen in dynamic algo
+        std::unordered_set<index> seenInDyn;
+
+        G.forNodes([&](node u) {
+            const auto staticCmpU = wc.componentOfNode(u), dynCmpU = dw.componentOfNode(u);
+            const auto it = compMap.find(staticCmpU);
+            if (it == compMap.end()) {
+                EXPECT_EQ(seenInDyn.find(dynCmpU), seenInDyn.end());
+                compMap.emplace(staticCmpU, dynCmpU);
+                seenInDyn.insert(dynCmpU);
+            } else
+                EXPECT_EQ(it->second, dynCmpU);
+        });
+    };
+
+    // Remove all edges
+    for (const auto &edge : edges) {
+        G.removeEdge(edge.u, edge.v);
+        dw.update(GraphEvent(GraphEvent::EDGE_REMOVAL, edge.u, edge.v));
+        testComponents();
     }
 
-    dw.updateBatch(batch);
-    wc.run();
-    EXPECT_EQ(wc.numberOfComponents(), dw.numberOfComponents());
+    // Add all edges
+    for (const auto &edge : edges) {
+        G.addEdge(edge.u, edge.v);
+        dw.update(GraphEvent(GraphEvent::EDGE_ADDITION, edge.u, edge.v));
+        testComponents();
+    }
 }
 
+TEST_F(ConnectedComponentsGTest, testDynWeaklyConnectedComponentsUndirected) {
+    Graph g(0);
+    EXPECT_THROW(DynWeaklyConnectedComponents{g}, std::runtime_error);
+}
+
+
 TEST_F(ConnectedComponentsGTest, testExtractLargestConnectedComponent) {
     Graph G(8);
 
