@@ -87,7 +87,7 @@ void Assortativity::run() {
             C += y * y;
         });
 
-        double r = A / sqrt(B * C);
+        double r = A / std::sqrt(B * C);
         coefficient = r;
     }
     hasRun = true;
@@ -98,13 +98,4 @@ double Assortativity::getCoefficient() const {
     return coefficient;
 }
 
-std::string Assortativity::toString() const {
-    return (std::string)"Assortativity("+((nominal)?"nominal":"ordinal")+")";
-}
-
-bool Assortativity::isParallel() const {
-    return false;
-}
-
-
 }
