@@ -19,6 +19,8 @@
 #include <networkit/distance/EffectiveDiameterApproximation.hpp>
 #include <networkit/distance/HopPlotApproximation.hpp>
 #include <networkit/distance/IncompleteDijkstra.hpp>
+#include <networkit/distance/MultiTargetBFS.hpp>
+#include <networkit/distance/MultiTargetDijkstra.hpp>
 #include <networkit/distance/NeighborhoodFunction.hpp>
 #include <networkit/distance/NeighborhoodFunctionApproximation.hpp>
 #include <networkit/distance/NeighborhoodFunctionHeuristic.hpp>
@@ -30,7 +32,37 @@
 #include <networkit/io/METISGraphReader.hpp>
 
 namespace NetworKit {
-class DistanceGTest: public testing::Test {};
+class DistanceGTest: public testing::TestWithParam<std::pair<bool, bool>> {
+
+protected:
+    static constexpr auto infdist = std::numeric_limits<edgeweight>::max();
+
+    bool isDirected() const noexcept;
+    bool isWeighted() const noexcept;
+
+    Graph generateERGraph(count n, double p) const {
+        auto G = ErdosRenyiGenerator(n, p, isDirected()).generate();
+        if (isWeighted()) {
+            G = GraphTools::toWeighted(G);
+            G.forEdges([&G](node u, node v) {
+                G.setWeight(u, v, Aux::Random::probability());
+            });
+        }
+
+        return G;
+    }
+};
+
+constexpr edgeweight DistanceGTest::infdist;
+
+INSTANTIATE_TEST_SUITE_P(InstantiationName, DistanceGTest,
+        testing::Values(std::make_pair(false, false), std::make_pair(true, false),
+                        std::make_pair(false, true),
+                        std::make_pair(true, true)));
+
+bool DistanceGTest::isWeighted() const noexcept { return GetParam().first; }
+
+bool DistanceGTest::isDirected() const noexcept { return GetParam().second; }
 
 TEST_F(DistanceGTest, testVertexDiameterPedantically) {
     DorogovtsevMendesGenerator generator(1000);
@@ -82,14 +114,12 @@ TEST_F(DistanceGTest, testAStar) {
                        (colU > colT ? colU - colT : colT - colU));
                 double rowDiff = std::abs(static_cast<double>(u / cols) - static_cast<double>(rowT));
                 double colDiff = std::abs(static_cast<double>(u % cols) - static_cast<double>(rowT));
-                eucledianDist[u] = sqrt(std::pow(rowDiff, 2) + std::pow(colDiff, 2));
+                eucledianDist[u] = std::sqrt(std::pow(rowDiff, 2) + std::pow(colDiff, 2));
             };
             BFS bfs(G, source, true, false, target);
             bfs.run();
 
-            std::vector<std::vector<double>> heuristics;
-
-            for (auto heu : heuristics) {
+            for (const auto &heu : {zeroDist, exactDist, eucledianDist}) {
                 AStar astar(G, heu, source, target, true);
                 astar.run();
                 EXPECT_EQ(astar.getDistance(), bfs.distance(target));
@@ -113,47 +143,37 @@ TEST_F(DistanceGTest, testAStar) {
     testMesh(25, 5);
 }
 
-TEST_F(DistanceGTest, testIncompleteDijkstra) {
+TEST_P(DistanceGTest, testIncompleteDijkstra) {
     Aux::Random::setSeed(42, false);
-    for (auto directed : {true, false}) {
-        for (auto weighted : {true, false}) {
-            auto G = ErdosRenyiGenerator(500, 0.05, directed).generate();
-            if (weighted) {
-                G = GraphTools::toWeighted(G);
-                G.forEdges([&G](const node u, const node v) {
-                    G.setWeight(u, v, Aux::Random::probability());
-                });
-            }
+    auto G = generateERGraph(500, 0.05);
 
-            G.forNodes([&](const node source) {
-                Dijkstra dij(G, source, false, false);
-                dij.run();
-                const auto dists = dij.getDistances();
-                const count reachable = std::count_if(dists.begin(), dists.end(),
-                                                      [](const edgeweight dist) {
-                    return dist != std::numeric_limits<edgeweight>::max();
-                });
+    G.forNodes([&](const node source) {
+        Dijkstra dij(G, source, false, false);
+        dij.run();
+        const auto dists = dij.getDistances();
+        const count reachable = std::count_if(dists.begin(), dists.end(),
+                                              [](const edgeweight dist) {
+            return dist != infdist;
+        });
 
-                const std::vector<node> sources({source});
-                IncompleteDijkstra iDij(&G, sources);
+        const std::vector<node> sources({source});
+        IncompleteDijkstra iDij(&G, sources);
 
-                for (count i = 0; i < reachable; ++i) {
-                    EXPECT_TRUE(iDij.hasNext());
-                    const auto next = iDij.next();
-                    EXPECT_DOUBLE_EQ(next.second, dists[next.first]);
-                }
-
-                EXPECT_FALSE(iDij.hasNext());
-            });
+        for (count i = 0; i < reachable; ++i) {
+            EXPECT_TRUE(iDij.hasNext());
+            const auto next = iDij.next();
+            EXPECT_DOUBLE_EQ(next.second, dists[next.first]);
         }
-    }
+
+        EXPECT_FALSE(iDij.hasNext());
+    });
 }
 
-TEST_F(DistanceGTest, testBidirectionalBFS) {
+TEST_P(DistanceGTest, testBidirectionalBFS) {
     Aux::Random::setSeed(42, false);
-    Graph G = ErdosRenyiGenerator(500, 0.02, false).generate();
-    Graph G1 = ErdosRenyiGenerator(500, 0.05, true).generate();
-    auto testGraph = [&](const Graph &G) {
+    auto G = generateERGraph(500, isDirected() ? 0.05 : 0.02);
+
+    for (int i = 0; i < 10; ++i) {
         node source = GraphTools::randomNode(G);
         node target = GraphTools::randomNode(G);
         while (source == target)
@@ -162,41 +182,30 @@ TEST_F(DistanceGTest, testBidirectionalBFS) {
         bfs.run();
         BidirectionalBFS bbfs(G, source, target, true);
         bbfs.run();
-        if (bfs.distance(target) < G.upperNodeIdBound())
+
+        if (bfs.distance(target) < G.upperNodeIdBound()) {
+            // Source reaches target
             EXPECT_EQ(bfs.distance(target), bbfs.getDistance());
-        else
-            EXPECT_EQ(std::numeric_limits<count>::max(), bbfs.getDistance());
-        auto path = bbfs.getPath();
-        EXPECT_EQ(path.size(), bbfs.getDistance() - 1);
-        if (path.size()) {
-            EXPECT_TRUE(G.hasEdge(source, path.front()));
-            EXPECT_TRUE(G.hasEdge(path.back(), target));
-            for (count i = 1; i < path.size()-1; ++i)
-                EXPECT_TRUE(G.hasEdge(path[i], path[i + 1]));
+            const auto path = bbfs.getPath();
+            EXPECT_EQ(path.size(), bbfs.getDistance() - 1);
+
+            if (!path.empty()) { // At least two edges in the path
+                EXPECT_TRUE(G.hasEdge(source, path.front()));
+                EXPECT_TRUE(G.hasEdge(path.back(), target));
+                for (count i = 1; i < path.size()-1; ++i)
+                    EXPECT_TRUE(G.hasEdge(path[i], path[i + 1]));
+            } else
+                EXPECT_TRUE(G.hasEdge(source, target));
         } else
-            EXPECT_TRUE(G.hasEdge(source, target));
+            EXPECT_EQ(infdist, bbfs.getDistance());
     };
-    for (int i = 0; i < 10; ++i) {
-        testGraph(G);
-        testGraph(G1);
-    }
 }
 
-TEST_F(DistanceGTest, testBidirectionalDijkstra) {
+TEST_P(DistanceGTest, testBidirectionalDijkstra) {
     Aux::Random::setSeed(42, false);
-    count n = 300;
-    Graph G(n, true, false);
-    Graph G1(n, true, true);
-    Graph gen = ErdosRenyiGenerator(n, 0.05, false).generate();
-    Graph gen1 = ErdosRenyiGenerator(n, 0.05, true).generate();
-    gen.forEdges([&](node u, node v) {
-        G.setWeight(u, v, Aux::Random::probability());
-    });
-    gen1.forEdges([&](node u, node v) {
-        G1.setWeight(u, v, Aux::Random::probability());
-    });
+    auto G = generateERGraph(500, isDirected() ? 0.05 : 0.02);
 
-    auto testGraph = [&](const Graph &G) {
+    for (int i = 0; i < 10; ++i) {
         node source = GraphTools::randomNode(G);
         node target = GraphTools::randomNode(G);
         while (source == target)
@@ -206,22 +215,23 @@ TEST_F(DistanceGTest, testBidirectionalDijkstra) {
         Dijkstra dij(G, source, true, true, target);
         dij.run();
 
-        EXPECT_NEAR(bdij.getDistance(), dij.distance(target), 1e-6);
-        auto path = bdij.getPath();
+        EXPECT_DOUBLE_EQ(bdij.getDistance(), dij.distance(target));
+        const auto path = bdij.getPath();
 
-        if (path.size()) {
-            EXPECT_TRUE(G.hasEdge(source, path.front()));
-            for (size_t i = 0; i < path.size() - 1; ++i)
-                EXPECT_TRUE(G.hasEdge(path[i], path[i + 1]));
-            EXPECT_TRUE(G.hasEdge(path.back(), target));
+        if (dij.distance(target) != infdist) {
+            // Source reaches target
+            EXPECT_DOUBLE_EQ(dij.distance(target), bdij.getDistance());
+
+            if (!path.empty()) { // At least two edges in the path
+                EXPECT_TRUE(G.hasEdge(source, path.front()));
+                for (size_t i = 0; i < path.size() - 1; ++i)
+                    EXPECT_TRUE(G.hasEdge(path[i], path[i + 1]));
+                EXPECT_TRUE(G.hasEdge(path.back(), target));
+            } else
+                EXPECT_TRUE(G.hasEdge(source, target));
         } else
-            EXPECT_TRUE(G.hasEdge(source, target));
+            EXPECT_EQ(infdist, bdij.getDistance());
     };
-
-    for (int i = 0; i < 10; ++i) {
-        testGraph(G);
-        testGraph(G1);
-    }
 }
 
 TEST_F(DistanceGTest, testExactDiameter) {
@@ -469,45 +479,100 @@ TEST_F(DistanceGTest, testNeighborhoodFunctionHeuristic) {
     EXPECT_EQ(exact.size(), heuristic.size());
 }
 
-TEST_F(DistanceGTest, testSPSP) {
+TEST_P(DistanceGTest, testSPSP) {
     for (int seed : {1, 2, 3}) {
         Aux::Random::setSeed(seed, true);
-        for (bool directed : {false, true}) {
-            for (bool weighted : {false, true}) {
-                auto G = ErdosRenyiGenerator(100, 0.15, directed).generate();
-                if (weighted) {
-                    G = GraphTools::toWeighted(G);
-                    G.forEdges([&](node u, node v) {
-                        G.setWeight(u, v, Aux::Random::probability());
-                    });
-                }
+        auto G = generateERGraph(100, 0.15);
 
-                APSP apsp(G);
-                apsp.run();
-                const auto gt = apsp.getDistances();
+        APSP apsp(G);
+        apsp.run();
+        const auto gt = apsp.getDistances();
 
-                for (count nSources : {1, 10, 50, 100}) {
-                    std::unordered_set<node> sources;
-                    do {
-                        sources.insert(GraphTools::randomNode(G));
-                    } while (sources.size() < nSources);
+        for (count nSources : {1, 10, 50, 100}) {
+            auto sources = GraphTools::randomNodes(G, nSources);
 
-                    SPSP spsp(G, sources.begin(), sources.end());
-                    spsp.run();
-                    const auto nodemap = spsp.getSourceIndexMap();
-                    const auto distances = spsp.getDistances();
+            SPSP spsp(G, sources.begin(), sources.end());
+            spsp.run();
+            const auto nodemap = spsp.getSourceIndexMap();
+            const auto distances = spsp.getDistances();
 
-                    for (node source : sources) {
-                        const auto &curDist = distances[nodemap.at(source)];
-                        G.forNodes([&](node target) {
-                            EXPECT_DOUBLE_EQ(gt[source][target], spsp.getDistance(source, target));
-                            EXPECT_DOUBLE_EQ(gt[source][target], curDist[target]);
-                        });
-                    }
-                }
+            for (node source : sources) {
+                const auto &curDist = distances[nodemap.at(source)];
+                G.forNodes([&](node target) {
+                    EXPECT_DOUBLE_EQ(gt[source][target], spsp.getDistance(source, target));
+                    EXPECT_DOUBLE_EQ(gt[source][target], curDist[target]);
+                });
             }
         }
     }
 }
 
+TEST_P(DistanceGTest, testSPSPWithTargets) {
+    Aux::Random::setSeed(42, true);
+    const auto G = generateERGraph(100, 0.15);
+
+    APSP apsp(G);
+    apsp.run();
+
+    for (count nSources : {1, 10, 100}) {
+        const auto sources = GraphTools::randomNodes(G, nSources);
+        for (count nTargets : {1, 50, 100}) {
+            const auto targets = GraphTools::randomNodes(G, nTargets);
+
+            SPSP spsp(G, sources.begin(), sources.end(), targets.begin(), targets.end());
+            spsp.run();
+            const auto sourceMap = spsp.getSourceIndexMap(), targetMap = spsp.getTargetIndexMap();
+            const auto distances = spsp.getDistances();
+            EXPECT_EQ(distances.size(), nSources);
+            EXPECT_EQ(distances.front().size(), nTargets);
+
+            for (node source : sources)
+                for (node target : targets)
+                    EXPECT_EQ(apsp.getDistance(source, target), spsp.getDistance(source, target));
+        }
+    }
+}
+
+TEST_P(DistanceGTest, testMultiTargetBFS) {
+    Aux::Random::setSeed(42, true);
+    const auto G = generateERGraph(100, 0.15);
+    const auto source = GraphTools::randomNode(G);
+
+    BFS bfs(G, source, false);
+    bfs.run();
+    const auto distances = bfs.getDistances();
+
+    for (count nTargets : {1, 10, 20}) {
+        const auto targets = GraphTools::randomNodes(G, nTargets);
+        MultiTargetBFS mtBFS(G, source, targets.begin(), targets.end());
+        mtBFS.run();
+        const auto tgtDists = mtBFS.getDistances();
+        const auto tgtIdx = mtBFS.getTargetIndexMap();
+
+        for (node target : targets)
+            EXPECT_EQ(distances[target], tgtDists[tgtIdx.at(target)]);
+    }
+}
+
+TEST_P(DistanceGTest, testMultiTargetDijkstra) {
+    Aux::Random::setSeed(42, true);
+    const auto G = generateERGraph(100, 0.15);
+    const auto source = GraphTools::randomNode(G);
+
+    Dijkstra dij(G, source, false);
+    dij.run();
+    const auto distances = dij.getDistances();
+
+    for (count nTargets : {1, 10, 20}) {
+        const auto targets = GraphTools::randomNodes(G, nTargets);
+        MultiTargetDijkstra mtDij(G, source, targets.begin(), targets.end());
+        mtDij.run();
+        const auto tgtDists = mtDij.getDistances();
+        const auto tgtIdx = mtDij.getTargetIndexMap();
+
+        for (node target : targets)
+            EXPECT_DOUBLE_EQ(distances[target], tgtDists[tgtIdx.at(target)]);
+    }
+}
+
 } /* namespace NetworKit */
