@@ -1,3 +1,4 @@
+// no-networkit-format
 /*
  * DynamicPathGenerator.cpp
  *
@@ -13,16 +14,16 @@ std::vector<GraphEvent> DynamicPathGenerator::generate(count nSteps) {
 
     std::vector<GraphEvent> stream;
     node u = G.addNode();
-    stream.push_back(GraphEvent(GraphEvent::NODE_ADDITION, u));
+    stream.emplace_back(GraphEvent::NODE_ADDITION, u);
 
     count step = 0;
     while (step < nSteps) {
         node v = G.addNode();
-        stream.push_back(GraphEvent(GraphEvent::NODE_ADDITION, v));
+        stream.emplace_back(GraphEvent::NODE_ADDITION, v);
         G.addEdge(u, v);
-        stream.push_back(GraphEvent(GraphEvent::EDGE_ADDITION, u, v, 1.0));
+        stream.emplace_back(GraphEvent::EDGE_ADDITION, u, v, 1.0);
         u = v;
-        stream.push_back(GraphEvent(GraphEvent::TIME_STEP));
+        stream.emplace_back(GraphEvent::TIME_STEP);
         step += 1;
     }
     return stream;
