@@ -11,10 +11,6 @@
 
 namespace NetworKit {
 
-std::string IndependentSetFinder::toString() const {
-    return "TODO: implement IndependentSetFinder.toString";
-}
-
 bool IndependentSetFinder::isIndependentSet(const std::vector<bool>& set, const Graph& G) const {
     bool result = true;
     G.forEdges([&](node u, node v) {
