@@ -28,5 +28,15 @@ class Test_CommunityDetection(unittest.TestCase):
 		hierarchy = community.CutClustering.getClusterHierarchy(jazz)
 		self.assertEqual(3, len(hierarchy))
 
+
+	def test_LFM(self):
+		local = scd.LFMLocal(self.G)
+		lfm = community.LFM(self.G, local)
+		lfm.run()
+		cover = lfm.getCover()
+		for u in self.G.iterNodes():
+			self.assertGreaterEqual(len(cover.subsetsOf(u)), 1)
+
+
 if __name__ == "__main__":
 	unittest.main()
