@@ -263,7 +263,32 @@ class TestGraph(unittest.TestCase):
 		self.assertEqual(G.numberOfNodes(), G2.numberOfNodes())
 		self.assertEqual(G.numberOfEdges(), G2.numberOfEdges())
 		self.assertEqual(G.edgeId(0,1), G2.edgeId(0,1))
-		
+
+	def testSpanningForest(self):
+		G = self.getSmallGraph()
+		sf = nk.graph.SpanningForest(G)
+		sf.run()
+		F = sf.getForest()
+
+		self.assertEqual(G.numberOfNodes(), F.numberOfNodes())
+		for u in F.iterNodes():
+			self.assertTrue(F.degree(u) > 0 or G.degree(u) == 0)
+
+		for u, v in F.iterEdges():
+			self.assertTrue(G.hasEdge(u, v))
+
+	def testNodeAttributes(self):
+		G = nk.Graph(5)
+
+		for attType in [int, float, str]:
+			attVals = [attType(i) for i in G.iterNodes()]
+
+			attrs = G.attachNodeAttribute("attribute", attType)
+			for u in G.iterNodes():
+				attrs[u] = attVals[u]
+				self.assertEqual(attrs[u], attVals[u])
+
+			G.detachNodeAttribute("attribute")
 
 if __name__ == "__main__":
 	unittest.main()
