@@ -1,6 +1,6 @@
 name='networkit'
 
-version='9.1.1'
+version='10.0'
 
 url='https://networkit.github.io/'
 
@@ -33,6 +33,7 @@ platforms = 'any'
 classifiers = [
 'Development Status :: 5 - Production/Stable',
 'Environment :: Console',
+'Environment :: Web Environment',
 'Environment :: Other Environment',
 'Framework :: IPython',
 'Intended Audience :: Developers',
@@ -41,16 +42,13 @@ classifiers = [
 'License :: OSI Approved :: MIT License',
 'Natural Language :: English',
 'Operating System :: OS Independent', 'Programming Language :: C++',
-'Programming Language :: Python :: 3.5',
-'Programming Language :: Python :: 3.6',
-'Programming Language :: Python :: 3.7',
-'Programming Language :: Python :: 3.8',
-'Programming Language :: Python :: 3.9',
+'Programming Language :: Python :: 3 :: Only',
 'Topic :: Software Development :: Libraries :: Python Modules',
 'Topic :: Scientific/Engineering :: Bio-Informatics',
 'Topic :: Scientific/Engineering :: Chemistry',
 'Topic :: Scientific/Engineering :: Information Analysis',
 'Topic :: Scientific/Engineering :: Mathematics',
+'Topic :: Scientific/Engineering :: Visualization'
 ]
 
 install_requires = [
